# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AddThreadToSpaceResponse(UniversalBaseModel):
    """
    Response for adding a thread to a space.
    """

    object: typing.Optional[str] = pydantic.Field(default=None)
    """
    Object type
    """

    success: bool = pydantic.Field()
    """
    Whether the operation was successful
    """

    message: str = pydantic.Field()
    """
    Operation result message
    """

    space_id: str = pydantic.Field()
    """
    Space ID
    """

    thread_id: str = pydantic.Field()
    """
    Thread ID
    """

    added_at: dt.datetime = pydantic.Field()
    """
    When thread was added
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
