# This file was auto-generated by Fern from our API Definition.

import typing

ReasoningConfigSchemaEffort = typing.Union[
    typing.Literal["off", "none", "low", "medium", "high", "maximum"], typing.Any
]
