# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .top_user_item import TopUserItem


class TopUsersResponse(UniversalBaseModel):
    """
    Response for top users ranking.
    """

    success: typing.Optional[bool] = None
    users: typing.List[TopUserItem] = pydantic.Field()
    """
    Ranked list of users
    """

    period: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Date range of the analysis
    """

    total_org_cost_chf: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total org cost for comparison
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
