# This file was auto-generated by Fern from our API Definition.

import typing

AssistantResponseAccessMode = typing.Union[
    typing.Literal["private", "organization", "department", "public"], typing.Any
]
