# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .editor_section import EditorSection


class EditorSchemaResponse(UniversalBaseModel):
    """
    Complete editor schema response returned by the API.
    """

    version: typing.Optional[int] = None
    sections: typing.List[EditorSection]
    field_types: typing.Dict[str, str]
    actions: typing.Dict[str, typing.Any]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
