# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .api_key_response import ApiKeyResponse


class ApiKeyActionResponse(UniversalBaseModel):
    """
    Response schema for API key actions (activate, deactivate, etc.).
    """

    success: bool = pydantic.Field()
    """
    Whether the action succeeded
    """

    message: str = pydantic.Field()
    """
    Action result message
    """

    key: typing.Optional[ApiKeyResponse] = pydantic.Field(default=None)
    """
    Updated key details
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
