# This file was auto-generated by Fern from our API Definition.

import typing

SchemaPropagationRequestPropagationStrategy = typing.Union[
    typing.Literal["propagate_fully", "propagate_columns", "ignore", "disable_connection"], typing.Any
]
