# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BulkGrantEntry(UniversalBaseModel):
    """
    A single entry in a bulk grant request.
    """

    grantee_type: str = pydantic.Field()
    """
    Type of grantee receiving access: 'user', 'department', or 'role'
    """

    grantee_id: str = pydantic.Field()
    """
    ID of the grantee receiving access
    """

    access_level: str = pydantic.Field()
    """
    Access level to grant: 'read', 'write', or 'admin'
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
