# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UserUsageSummary(UniversalBaseModel):
    """
    Single user's usage summary.
    """

    user_id: str = pydantic.Field()
    """
    User ID
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    User's full name
    """

    email: str = pydantic.Field()
    """
    User's email
    """

    all_time: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    All-time usage metrics
    """

    current_month: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Current month metrics
    """

    top_models: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = pydantic.Field(default=None)
    """
    Top models used
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
