# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ReasoningEffortOption(UniversalBaseModel):
    """
    A single reasoning effort option.
    """

    value: str = pydantic.Field()
    """
    Effort level value (e.g., 'low', 'medium')
    """

    label: str = pydantic.Field()
    """
    Human-readable label
    """

    description: str = pydantic.Field()
    """
    Short description of the effort level
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
