# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .space_vector_store_entry import SpaceVectorStoreEntry


class SpaceVectorStoreListResponse(UniversalBaseModel):
    """
    Response for listing additional vector stores of a space.

    Results are bounded by the per-space limit (max 20) and are not paginated.
    """

    object: typing.Optional[str] = pydantic.Field(default=None)
    """
    Object type
    """

    vector_stores: typing.List[SpaceVectorStoreEntry] = pydantic.Field()
    """
    Additional vector stores attached to this space. Results are bounded (max 20 per space) and returned in full — no pagination.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
