# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class PinActionResponse(UniversalBaseModel):
    """
    Response for pin/unpin actions.
    """

    success: bool = pydantic.Field()
    """
    Whether the operation succeeded
    """

    pinned: bool = pydantic.Field()
    """
    Current pin state after the operation
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
