# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .editor_field import EditorField
from .editor_subsection import EditorSubsection


class EditorSection(UniversalBaseModel):
    """
    Top-level section in the editor layout.
    """

    id: str
    label: str
    icon: typing.Optional[str] = None
    collapsible: typing.Optional[bool] = None
    default_collapsed: typing.Optional[bool] = None
    fields: typing.Optional[typing.List[EditorField]] = None
    subsections: typing.Optional[typing.List[EditorSubsection]] = None
    toggle: typing.Optional[typing.Dict[str, typing.Any]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
