# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .organization_basic_info import OrganizationBasicInfo


class SetCurrentOrganizationResponse(UniversalBaseModel):
    """
    Response schema for setting current organization.
    """

    success: bool = pydantic.Field()
    """
    Whether the operation was successful
    """

    message: str = pydantic.Field()
    """
    Success message
    """

    current_organization_id: str = pydantic.Field()
    """
    The new current organization ID
    """

    organization: OrganizationBasicInfo = pydantic.Field()
    """
    Organization details
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
