# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .system_usage_item import SystemUsageItem


class SystemBreakdownResponse(UniversalBaseModel):
    """
    Response for system cost breakdown.
    """

    success: typing.Optional[bool] = None
    systems: typing.Optional[typing.List[SystemUsageItem]] = pydantic.Field(default=None)
    """
    System usage breakdown
    """

    total_cost_chf: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total cost across all systems
    """

    period: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Date range of the analysis
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
