# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AnomalyItem(UniversalBaseModel):
    """
    Single cost anomaly.
    """

    date: str = pydantic.Field()
    """
    Date of anomaly (YYYY-MM-DD)
    """

    actual_cost_chf: typing.Optional[float] = pydantic.Field(default=None)
    """
    Actual cost on that day
    """

    expected_cost_chf: typing.Optional[float] = pydantic.Field(default=None)
    """
    Expected cost based on rolling average
    """

    deviation_pct: typing.Optional[float] = pydantic.Field(default=None)
    """
    Deviation percentage from expected
    """

    probable_cause: typing.Optional[str] = pydantic.Field(default=None)
    """
    Heuristic probable cause
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
