# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SearchResult(UniversalBaseModel):
    """
    A single search result from cross-meeting search.
    """

    session_id: str
    session_title: str
    meeting_date: typing.Optional[dt.datetime] = None
    matched_snippet: str
    relevance_score: float
    chunk_type: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
