# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class PipelineSyncResponse(UniversalBaseModel):
    status: str = pydantic.Field()
    """
    Sync result status (e.g. 'completed')
    """

    workspaces_synced: int = pydantic.Field()
    """
    Number of workspaces synced
    """

    source_definitions_refreshed: int = pydantic.Field()
    """
    Total source definitions refreshed across all workspaces
    """

    caches_cleared: typing.List[str] = pydantic.Field()
    """
    List of cache keys that were invalidated
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Human-readable summary of the sync result
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
