# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class PipelineProcessingDetails(UniversalBaseModel):
    """
    Detailed breakdown of processing results.
    """

    inserted: typing.Optional[int] = pydantic.Field(default=None)
    """
    New records created
    """

    updated: typing.Optional[int] = pydantic.Field(default=None)
    """
    Records updated (content changed)
    """

    skipped_unchanged: typing.Optional[int] = pydantic.Field(default=None)
    """
    Records with no content changes
    """

    skipped_older: typing.Optional[int] = pydantic.Field(default=None)
    """
    Records with older timestamps
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
