# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OrganizationInfo(UniversalBaseModel):
    """
    Organization information for email validation response.
    """

    id: str = pydantic.Field()
    """
    Organization ID
    """

    name: str = pydantic.Field()
    """
    Organization name
    """

    logo: typing.Optional[str] = pydantic.Field(default=None)
    """
    Organization logo URL
    """

    requires_invitation: bool = pydantic.Field()
    """
    Whether the organization requires an invitation to join
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
