# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .system_usage_item import SystemUsageItem


class UnifiedDashboardResponse(UniversalBaseModel):
    """
    Response for the executive unified dashboard.
    """

    success: typing.Optional[bool] = None
    total_cost_chf: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total cost across all systems
    """

    month_over_month_change_pct: typing.Optional[float] = pydantic.Field(default=None)
    """
    Month-over-month change percentage
    """

    projected_monthly_cost_chf: typing.Optional[float] = pydantic.Field(default=None)
    """
    Projected monthly cost at current rate
    """

    systems: typing.Optional[typing.List[SystemUsageItem]] = pydantic.Field(default=None)
    """
    System breakdown
    """

    monthly_trend: typing.Optional[typing.List[typing.Dict[str, typing.Any]]] = pydantic.Field(default=None)
    """
    Monthly cost trend data
    """

    top_cost_drivers: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Top cost drivers by model, user, system
    """

    organization_id: str = pydantic.Field()
    """
    Organization ID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
