# This file was auto-generated by Fern from our API Definition.

import typing

AssistantResponseResponseFormat = typing.Union[typing.Literal["auto", "text", "json_object", "json_schema"], typing.Any]
