# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .editor_field import EditorField


class EditorSubsection(UniversalBaseModel):
    """
    A subsection within a section, containing related fields.
    """

    id: str
    label: str
    icon: typing.Optional[str] = None
    collapsible: typing.Optional[bool] = None
    fields: typing.List[EditorField]
    visible_when_has: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
