# This file was auto-generated by Fern from our API Definition.

import typing

ListAssistantsV1AssistantsGetRequestSortBy = typing.Union[
    typing.Literal["name", "created_at", "updated_at"], typing.Any
]
