# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class TriggerSubscriptionResponse(UniversalBaseModel):
    """
    Response for a single trigger subscription. API key is never exposed.
    """

    id: str
    user_id: str
    organization_id: str
    provider: str
    event_type: str
    connection_id: typing.Optional[str] = None
    flow_id: str
    trigger_name: str
    enabled: bool
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
