# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class StoreUsageEntry(UniversalBaseModel):
    """
    Usage stats for a single store.
    """

    store_id: str = pydantic.Field()
    """
    Vector store identifier
    """

    store_name: str = pydantic.Field()
    """
    Vector store name
    """

    used_bytes: int = pydantic.Field()
    """
    Bytes used by this store
    """

    file_count: int = pydantic.Field()
    """
    Number of files in this store
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
