# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AccessOverviewSlice(UniversalBaseModel):
    """
    Slice metadata for access overview (no content).
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the slice
    """

    name: str = pydantic.Field()
    """
    Display name of the slice
    """

    is_composite: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether this is a composite slice
    """

    created_by: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the user who created this slice
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
