# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class KnowledgeVectorStoreResponse(UniversalBaseModel):
    """
    Schema for vector store response in knowledge context.
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the vector store
    """

    name: str = pydantic.Field()
    """
    Display name of the vector store
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description of the vector store
    """

    slice_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the primary associated slice
    """

    slice_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    IDs of all slices this vector store is associated with
    """

    organization_id: str = pydantic.Field()
    """
    ID of the organization this vector store belongs to
    """

    created_by: str = pydantic.Field()
    """
    ID of the user who created this vector store
    """

    is_active: bool = pydantic.Field()
    """
    Whether this vector store is currently active
    """

    access_mode: str = pydantic.Field()
    """
    Access control mode: 'organization', 'department', 'private', or 'public'
    """

    file_count: int = pydantic.Field()
    """
    Number of files stored in this vector store
    """

    data_size: int = pydantic.Field()
    """
    Total data size in bytes across all files in the vector store
    """

    created_at: dt.datetime = pydantic.Field()
    """
    Timestamp when the vector store was created
    """

    updated_at: dt.datetime = pydantic.Field()
    """
    Timestamp when the vector store was last updated
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
