# This file was auto-generated by Fern from our API Definition.

import typing

ConfigFieldType = typing.Union[
    typing.Literal[
        "text",
        "integer",
        "number",
        "toggle",
        "date_time",
        "dropdown",
        "multi_select",
        "multi_text",
        "group_select",
        "folder_picker",
    ],
    typing.Any,
]
