# This file was auto-generated by Fern from our API Definition.

import typing

AssistantCreateOutputMode = typing.Union[
    typing.Literal["text", "plain", "structured", "json", "json_schema"], typing.Any
]
