# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DeleteMessageResponse(UniversalBaseModel):
    """
    Response schema for deleted message.
    """

    id: str = pydantic.Field()
    """
    Deleted message ID with msg_ prefix
    """

    deleted: typing.Optional[typing.Literal[True]] = pydantic.Field(default=None)
    """
    Deletion confirmation
    """

    object: typing.Optional[typing.Literal["thread.message.deleted"]] = pydantic.Field(default=None)
    """
    Object type identifier
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
