# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .preset_info import PresetInfo


class PermissionPresetResponse(UniversalBaseModel):
    """
    Response for GET /permission-preset.
    """

    current_preset: str
    current_description: str
    member_capabilities: typing.List[str]
    available_presets: typing.List[PresetInfo]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
